# Wavin Sentio
> API Wrapper for Wavin Sentio underfloor heating system.

Enables you to query status of thermostats and change target temperature

## Usage example

ws = wavinsentio.WavinSentio("username","password")

## Release History

* 0.1.0
    * The first proper release
* 0.2.0
    * Added setTemperature, setProfile and refresh token logic
* 0.2.1
    * PyPi push
* 0.2.2
    * Cleaned folder structure
* 0.2.3
    * Fixed error handling
